@@ -13,15 +13,15 @@ data(predimed)
 ## ----echo=FALSE,results="asis"----------------------------------------------------------------------------------------------------------------------
 dicc <- data.frame(
 "Name"=I(names(predimed)),
-"Label"=I(unlist(lapply(predimed, Hmisc::label))),
+"Label"=I(unlist(lapply(predimed, attr, which="label", exact=TRUE))),
 "Codes"=I(unlist(lapply(predimed, function(x) paste(levels(x),collapse="; "))))
 )
 dicc$Codes <- sub(">=","$\\\\geq$",dicc$Codes)
-print(xtable(dicc,align=rep("l",4)),include.rownames=FALSE,type="html")
+kable(dicc, align=rep("l",4), row.names=FALSE, format = "html")
 
 ## ---------------------------------------------------------------------------------------------------------------------------------------------------
 predimed$tmain <- with(predimed, Surv(toevent, event == 'Yes'))
-Hmisc::label(predimed$tmain) <- "AMI, stroke, or CV Death"
+attr(predimed$tmain,"label") <- "AMI, stroke, or CV Death"
 
 ## ---- results='hide'--------------------------------------------------------------------------------------------------------------------------------
 compareGroups(group ~ . , data=predimed)
@@ -92,7 +92,7 @@ compareGroups(group ~ age + smoke + waist + hormo, data=predimed, method = c(wai
 ## ---- echo=TRUE-------------------------------------------------------------------------------------------------------------------------------------
 predimed$smk<-predimed$smoke
 levels(predimed$smk)<- c("Never smoker", "Current or former < 1y", "Never or former >= 1y", "Unknown")
-Hmisc::label(predimed$smk)<-"Smoking 4 cat."
+attr(predimed$smk,"label")<-"Smoking 4 cat."
 cbind(table(predimed$smk))
 
 ## ---- eval=FALSE------------------------------------------------------------------------------------------------------------------------------------
